# -*- coding: utf-8 -*-
#

__version__ = '0.1.1'
__author__ = u'Nico Schlömer'
__author_email__ = 'nico.schloemer@gmail.com'
__status__ = 'Development Status :: 3 - Alpha'
__license__ = 'License :: OSI Approved :: MIT License'
